---
title: jellyfin
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.jellyfin) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.jellyfin?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.jellyfin) [![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/ansible/xoxys.jellyfin/src/branch/master/LICENSE) 

Setup a [Jellyfin](https://jellyfin.org/) server. Jellyfin puts you in control of managing and streaming your media. Jellyfin requires a working `ffmpeg` and `aspnetcore-runtime` on the target host and the setup is not covered by this role!

* [Default Variables](#default-variables)
  * [jellyfin_base_dir](#jellyfin_base_dir)
  * [jellyfin_cache_dir](#jellyfin_cache_dir)
  * [jellyfin_conf_dir](#jellyfin_conf_dir)
  * [jellyfin_data_dir](#jellyfin_data_dir)
  * [jellyfin_extra_groups](#jellyfin_extra_groups)
  * [jellyfin_ffmpeg_bin](#jellyfin_ffmpeg_bin)
  * [jellyfin_group](#jellyfin_group)
  * [jellyfin_log_dir](#jellyfin_log_dir)
  * [jellyfin_log_level_console](#jellyfin_log_level_console)
  * [jellyfin_log_level_file](#jellyfin_log_level_file)
  * [jellyfin_packages_extra](#jellyfin_packages_extra)
  * [jellyfin_selinux_fcontext](#jellyfin_selinux_fcontext)
  * [jellyfin_selinux_restorecon](#jellyfin_selinux_restorecon)
  * [jellyfin_src_dir](#jellyfin_src_dir)
  * [jellyfin_user](#jellyfin_user)
  * [jellyfin_user_home](#jellyfin_user_home)
  * [jellyfin_version](#jellyfin_version)
* [Dependencies](#dependencies)

---

## Default Variables

### jellyfin_base_dir

#### Default value

```YAML
jellyfin_base_dir: /opt/jellyfin
```

### jellyfin_cache_dir

#### Default value

```YAML
jellyfin_cache_dir: '{{ jellyfin_base_dir }}/cache'
```

### jellyfin_conf_dir

#### Default value

```YAML
jellyfin_conf_dir: '{{ jellyfin_base_dir }}/config'
```

### jellyfin_data_dir

#### Default value

```YAML
jellyfin_data_dir: '{{ jellyfin_base_dir }}/data'
```

### jellyfin_extra_groups

#### Default value

```YAML
jellyfin_extra_groups: []
```

### jellyfin_ffmpeg_bin

#### Default value

```YAML
jellyfin_ffmpeg_bin: /usr/bin/ffmpeg
```

### jellyfin_group

#### Default value

```YAML
jellyfin_group: '{{ jellyfin_user }}'
```

### jellyfin_log_dir

#### Default value

```YAML
jellyfin_log_dir: '{{ jellyfin_base_dir }}/log'
```

### jellyfin_log_level_console

Possible value: `Verbose | Debug | Information | Warning | Error | Fatal`. Beware that the values are case sensitive!

#### Default value

```YAML
jellyfin_log_level_console: Fatal
```

### jellyfin_log_level_file

#### Default value

```YAML
jellyfin_log_level_file: Information
```

### jellyfin_packages_extra

#### Default value

```YAML
jellyfin_packages_extra: []
```

### jellyfin_selinux_fcontext

#### Default value

```YAML
jellyfin_selinux_fcontext:
  - target: '{{ jellyfin_log_dir }}(/.*)?'
    setype: var_log_t
```

### jellyfin_selinux_restorecon

#### Default value

```YAML
jellyfin_selinux_restorecon:
  - -ir {{ jellyfin_log_dir }}
```

### jellyfin_src_dir

#### Default value

```YAML
jellyfin_src_dir: '{{ jellyfin_base_dir }}/src'
```

### jellyfin_user

#### Default value

```YAML
jellyfin_user: jellyfin
```

### jellyfin_user_home

#### Default value

```YAML
jellyfin_user_home: /home/{{ jellyfin_user }}
```

### jellyfin_version

#### Default value

```YAML
jellyfin_version: 10.7.2
```

## Dependencies

None.
